==> nextcloud-29.0.12.tgz: nextcloud/apps/password_policy/l10n/ca.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "La contrasenya ha caducat, utilitzeu el mètode de recuperació de contrasenya per a reinicialitzar-la",
    "Password must not have been used recently before." : "La contrasenya no es pot haver utilitzat recentment abans.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "La contrasenya es troba entre les 1.000.000 més freqüents. Indiqueu una contrasenya única.",
    "Password is present in compromised password list. Please choose a different password." : "La contrasenya forma part de la llista de contrasenyes compromeses. Trieu una contrasenya diferent.",
    "Password needs to be at least %s characters long." : "La contrasenya ha de tenir com a mínim %s caràcters.",
    "Password needs to contain at least one numeric character." : "La contrasenya ha de contenir com a mínim un caràcter numèric.",
    "Password needs to contain at least one special character." : "La contrasenya ha de contenir com a mínim un caràcter especial.",
    "Password needs to contain at least one lower and one upper case character." : "La contrasenya ha de contenir com a mínim un caràcter en majúscula i un en minúscula.",
    "Password policy" : "Política de contrasenyes",
    "Allows admins to configure a password policy" : "Permet que els administradors configurin una política de contrasenyes",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permet que l'administrador defineixi determinades condicions prèvies per a les contrasenyes; p. ex., una longitud mínima",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Nombre d'intents d'inici de sessió abans d'inhabilitar el compte d'usuari fins que hi hagi una acció manual. (0: sense límit)",
    "Number of days until user password expires" : "Nombre de dies fins que caduca la contrasenya de l'usuari",
    "Minimum password length" : "Longitud mínima de la contrasenya",
    "Forbid common passwords" : "Prohibeix les contrasenyes freqüents",
    "Enforce upper and lower case characters" : "Força els caràcters en majúscula i minúscula",
    "Enforce numeric characters" : "Força els caràcters numèrics",
    "Enforce special characters" : "Força els caràcters especials",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Comprova la contrasenya amb la llista de contrasenyes compromeses de haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Aquesta comprovació crea una suma de verificació de la contrasenya i n'envia els 5 primers caràcters a l'API de haveibeenpwned.com per a recuperar una llista de totes les sumes de verificació que comencen per aquests caràcters. A continuació, comprova a la instància del Nextcloud si la contrasenya es troba en el conjunt de resultats.",
    "User password history" : "Historial de contrasenyes de l'usuari",
    "Please note, that this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Tingueu en compte que aquesta opció té la intenció de protegir els comptes atacats. L'administració ha de tornar a habilitar els comptes inhabilitats manualment. Si els atacants intenten endevinar les contrasenyes dels comptes, la protecció contra els atacs de força bruta (independent d'aquest paràmetre) en blocarà l'adreça IP.",
    "Unknown error" : "Error desconegut",
    "Minimal length has to be a non negative number" : "La longitud mínima ha de ser un nombre no negatiu",
    "History size has to be a non negative number" : "La mida de l'historial ha de ser un nombre no negatiu",
    "Expiration days have to be a non negative number" : "El nombre de dies de caducitat ha de ser un nombre no negatiu",
    "Maximum login attempts have to be a non negative number" : "El nombre màxim d'intents d'inici de sessió ha de ser un nombre no negatiu",
    "Settings saved" : "S'han desat els paràmetres",
    "Error while saving settings" : "S'ha produït un error en desar els paràmetres"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/password_policy/l10n/ca.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "La contrasenya ha caducat, utilitzeu el mètode de recuperació de contrasenya per a reinicialitzar-la",
    "Password must not have been used recently before." : "La contrasenya no es pot haver utilitzat recentment abans.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "La contrasenya es troba entre les 1.000.000 més freqüents. Indiqueu una contrasenya única.",
    "Password is present in compromised password list. Please choose a different password." : "La contrasenya forma part de la llista de contrasenyes compromeses. Trieu una contrasenya diferent.",
    "Password needs to be at least %s characters long." : "La contrasenya ha de tenir com a mínim %s caràcters.",
    "Password needs to contain at least one numeric character." : "La contrasenya ha de contenir com a mínim un caràcter numèric.",
    "Password needs to contain at least one special character." : "La contrasenya ha de contenir com a mínim un caràcter especial.",
    "Password needs to contain at least one lower and one upper case character." : "La contrasenya ha de contenir com a mínim un caràcter en majúscula i un en minúscula.",
    "Password policy" : "Política de contrasenyes",
    "Allows admins to configure a password policy" : "Permet que els administradors configurin una política de contrasenyes",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permet que l'administrador defineixi determinades condicions prèvies per a les contrasenyes; p. ex., una longitud mínima",
    "Minimum password length" : "Longitud mínima de la contrasenya",
    "User password history" : "Historial de contrasenyes de l'usuari",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Nombre d'intents d'inici de sessió abans d'inhabilitar el compte d'usuari fins que hi hagi una acció manual. (0: sense límit)",
    "Number of days until user password expires" : "Nombre de dies fins que caduca la contrasenya de l'usuari",
    "Forbid common passwords" : "Prohibeix les contrasenyes freqüents",
    "Enforce upper and lower case characters" : "Força els caràcters en majúscula i minúscula",
    "Enforce numeric characters" : "Força els caràcters numèrics",
    "Enforce special characters" : "Força els caràcters especials",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Comprova la contrasenya amb la llista de contrasenyes compromeses de haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Aquesta comprovació crea una suma de verificació de la contrasenya i n'envia els 5 primers caràcters a l'API de haveibeenpwned.com per a recuperar una llista de totes les sumes de verificació que comencen per aquests caràcters. A continuació, comprova a la instància del Nextcloud si la contrasenya es troba en el conjunt de resultats.",
    "Unknown error" : "Error desconegut",
    "Minimal length has to be a non negative number" : "La longitud mínima ha de ser un nombre no negatiu",
    "History size has to be a non negative number" : "La mida de l'historial ha de ser un nombre no negatiu",
    "Expiration days have to be a non negative number" : "El nombre de dies de caducitat ha de ser un nombre no negatiu",
    "Maximum login attempts have to be a non negative number" : "El nombre màxim d'intents d'inici de sessió ha de ser un nombre no negatiu",
    "Settings saved" : "S'han desat els paràmetres",
    "Error while saving settings" : "S'ha produït un error en desar els paràmetres",
    "Please note, that this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Tingueu en compte que aquesta opció té la intenció de protegir els comptes atacats. L'administració ha de tornar a habilitar els comptes inhabilitats manualment. Si els atacants intenten endevinar les contrasenyes dels comptes, la protecció contra els atacs de força bruta (independent d'aquest paràmetre) en blocarà l'adreça IP."
},
"nplurals=2; plural=(n != 1);");
